package nsdb.NucFeaturePackage;
public final class QualifierValue_u
	implements org.omg.CORBA.portable.IDLEntity
{
	private int discriminator;
	private type.DbXref db_xref;
	private type.RepeatUnit repeat_unit;
	private type.SpliceConsensus splice_consensus;
	private type.AntiCodon anti_codon;
	private type.CodonTranslation codon_translation;
	private type.TranslationException translation_exception;
	private float real;
	private int integer;
	private java.lang.String text;
	private boolean applicable;
	public QualifierValue_u()
	{
	}

	public int discriminator()
	{
		return discriminator;
	}

	public type.DbXref db_xref()
	{
		if( discriminator != 22)
			throw new org.omg.CORBA.BAD_OPERATION();
		return db_xref;
	}

	public void db_xref( type.DbXref _x )
	{
		discriminator = 22;
		db_xref = _x;
	}

	public type.RepeatUnit repeat_unit()
	{
		if( discriminator != 21)
			throw new org.omg.CORBA.BAD_OPERATION();
		return repeat_unit;
	}

	public void repeat_unit( type.RepeatUnit _x )
	{
		discriminator = 21;
		repeat_unit = _x;
	}

	public type.SpliceConsensus splice_consensus()
	{
		if( discriminator != 20)
			throw new org.omg.CORBA.BAD_OPERATION();
		return splice_consensus;
	}

	public void splice_consensus( type.SpliceConsensus _x )
	{
		discriminator = 20;
		splice_consensus = _x;
	}

	public type.AntiCodon anti_codon()
	{
		if( discriminator != 19)
			throw new org.omg.CORBA.BAD_OPERATION();
		return anti_codon;
	}

	public void anti_codon( type.AntiCodon _x )
	{
		discriminator = 19;
		anti_codon = _x;
	}

	public type.CodonTranslation codon_translation()
	{
		if( discriminator != 18)
			throw new org.omg.CORBA.BAD_OPERATION();
		return codon_translation;
	}

	public void codon_translation( type.CodonTranslation _x )
	{
		discriminator = 18;
		codon_translation = _x;
	}

	public type.TranslationException translation_exception()
	{
		if( discriminator != 17)
			throw new org.omg.CORBA.BAD_OPERATION();
		return translation_exception;
	}

	public void translation_exception( type.TranslationException _x )
	{
		discriminator = 17;
		translation_exception = _x;
	}

	public float real()
	{
		if( discriminator != 4)
			throw new org.omg.CORBA.BAD_OPERATION();
		return real;
	}

	public void real( float _x )
	{
		discriminator = 4;
		real = _x;
	}

	public int integer()
	{
		if( discriminator != 3)
			throw new org.omg.CORBA.BAD_OPERATION();
		return integer;
	}

	public void integer( int _x )
	{
		discriminator = 3;
		integer = _x;
	}

	public java.lang.String text()
	{
		if( discriminator != 1)
			throw new org.omg.CORBA.BAD_OPERATION();
		return text;
	}

	public void text( java.lang.String _x )
	{
		discriminator = 1;
		text = _x;
	}

	public boolean applicable()
	{
		if( discriminator != 2)
			throw new org.omg.CORBA.BAD_OPERATION();
		return applicable;
	}

	public void applicable( boolean _x )
	{
		discriminator = 2;
		applicable = _x;
	}

	public void __default()
	{
		discriminator = 0;
	}
	public void __default( int _discriminator )
	{
		discriminator = _discriminator;
	}
}
